;-------------------------------------------------------------
;    Userlib: password functions and common useful functions
;		by the Doors Team
;	xvassor@mail.dotcom.fr   or	deucalion@mail.dotcom.fr
;		http://doorshome.home.ml.org
;-------------------------------------------------------------


userlib::idle_loop	equ	userlib@0001
;---------------------------------------------------------------------
;idle_loop(void)
;
;   Wait for a key press. Diamond-ON turn off the calculator;
;   any other key will cause the function to return. This function
;   also supports APD (Auto Power Down).
;
;Input: nothing
;
;Output: d0.w = getkey code of key pressed
;	NO OTHER REGISTERS DETROYED
;---------------------------------------------------------------------

userlib::idle_hot	equ	userlib@0000
;---------------------------------------------------------------------
;idle_hot(void)
;
;   Same as idle_loop but:
;	-pressing the F7 HotKey will protect your calc by turning off 
;	and asking for a password
;	-pressing the F8 HotKey will turn off your calc
;
;Input: nothing
;
;Output: d0.w = getkey code of key pressed
;	NO OTHER REGISTERS DETROYED
;---------------------------------------------------------------------

userlib::getpassword	equ	userlib@0002
;---------------------------------------------------------------------
;getpassword(void)
;
;   Asks for the Doors password and return in d1 the result
;
;Input: nothing
;
;Output: d1.w = 0  -> Good password
;	Otherwise the password was bad.
;
;	NO OTHER REGISTERS DETROYED
;---------------------------------------------------------------------

userlib::strcomp	equ	userlib@0003
;---------------------------------------------------------------------
;strcomp(str1,str2)
;
;   Compares str1 and str2
;
;Input:	a0.l = str1
;	a1.l = str2
;
;Output: d1.w = 0  -> str1 = str2
;	Otherwise str1 <> str2
;
;	NO OTHER REGISTERS DETROYED
;---------------------------------------------------------------------

userlib::changepass	equ	userlib@0004
;---------------------------------------------------------------------
;changepass(void)
;
;   Asks for the old Doors password and if it is good, asks for a new Doors password
;
;Input and Output: nothing
;
;   NO REGISTERS DESTROYED
;---------------------------------------------------------------------

userlib::lockcalc	equ	userlib@0005
;---------------------------------------------------------------------
;lockcalc(void)
;
;   Turn off the TI 92. When turned on, the Doors password is asked.
;	If the password is bad, the calc is turned off again.
;
;Input: nothing
;
;Output: d4=0 -> screen wasn't restored
;
;   NO OTHER REGISTERS DESTROYED
;
;NOTE:this function requires 3840 bytes free to save the screen and later restore it.
;  If there isn't place enough, the screen wont'be restored.
;---------------------------------------------------------------------

userlib::InputStr	equ	userlib@0006
;---------------------------------------------------------------------
; InputStr(x,y,maxchar)
;
;   Inputs a string at x,y
;
;Input:	d1.w = x
;	d2.w = y
;	d3.w = maxchar
;
;Output: d0.w = string lenght
;	 a0.l = adress of the string
;---------------------------------------------------------------------

userlib::getfreemem	equ	userlib@0007
;---------------------------------------------------------------------
;  getfreemem(void)
;
;	returns the free memory, in bytes
;
;Input: nothing
;
;Output: d0.l = number of bytes free in memory
;
;	NO OTHER REGISTERS DESTROYED
;---------------------------------------------------------------------
